@@ -1,9 +1,19 @@
-from wsgiref.simple_server import WSGIServer, WSGIRequestHandler
+from typing import Callable
+from wsgiref.simple_server import WSGIRequestHandler, WSGIServer
 
-from rivr.wsgi import WSGIHandler
+from rivr.http import Request, Response
 from rivr.middleware.debug import DebugMiddleware
+from rivr.wsgi import WSGIHandler
 
-def serve(handler, host='localhost', port=8080, debug=True):
+__all__ = ['serve']
+
+
+def serve(
+    handler: Callable[[Request], Response],
+    host: str = 'localhost',
+    port: int = 8080,
+    debug: bool = True,
+):
     """
     Starts a developent server on the local machine. By default, the
     server runs on port 8080 on localhost. You can pass in a different
